==> xulrunner-21.0a1.en-US.win32.sdk.zip: xulrunner-sdk/include/nsFrameIdList.h <==
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

FRAME_ID(BRFrame)
FRAME_ID(nsAutoRepeatBoxFrame)
FRAME_ID(nsBCTableCellFrame)
FRAME_ID(nsBlockFrame)
FRAME_ID(nsBox)
FRAME_ID(nsBoxFrame)
FRAME_ID(nsBulletFrame)
FRAME_ID(nsButtonBoxFrame)
FRAME_ID(nsCanvasFrame)
FRAME_ID(nsColumnSetFrame)
FRAME_ID(nsComboboxControlFrame)
FRAME_ID(nsComboboxDisplayFrame)
FRAME_ID(nsContainerFrame)
FRAME_ID(nsContinuingTextFrame)
FRAME_ID(nsDeckFrame)
FRAME_ID(nsDocElementBoxFrame)
FRAME_ID(nsFieldSetFrame)
FRAME_ID(nsFileControlFrame)
FRAME_ID(nsFirstLetterFrame)
FRAME_ID(nsFirstLineFrame)
FRAME_ID(nsFlexContainerFrame)
FRAME_ID(nsFormControlFrame)
FRAME_ID(nsFrame)
FRAME_ID(nsGfxButtonControlFrame)
FRAME_ID(nsGfxCheckboxControlFrame)
FRAME_ID(nsGfxRadioControlFrame)
FRAME_ID(nsGridRowGroupFrame)
FRAME_ID(nsGridRowLeafFrame)
FRAME_ID(nsGroupBoxFrame)
FRAME_ID(nsHTMLButtonControlFrame)
FRAME_ID(nsHTMLCanvasFrame)
FRAME_ID(nsHTMLFramesetBlankFrame)
FRAME_ID(nsHTMLFramesetBorderFrame)
FRAME_ID(nsHTMLFramesetFrame)
FRAME_ID(nsHTMLScrollFrame)
FRAME_ID(nsIAnonymousContentCreator)
FRAME_ID(nsIComboboxControlFrame)
FRAME_ID(nsIFormControlFrame)
FRAME_ID(nsIFrame)
FRAME_ID(nsIFrameFrame)
FRAME_ID(nsIListControlFrame)
FRAME_ID(nsIMathMLFrame)
FRAME_ID(nsIMenuFrame)
FRAME_ID(nsIObjectFrame)
FRAME_ID(nsIPageSequenceFrame)
FRAME_ID(nsIPercentHeightObserver)
FRAME_ID(nsIRootBox)
FRAME_ID(nsISVGChildFrame)
FRAME_ID(nsISVGGlyphFragmentLeaf)
FRAME_ID(nsISVGGlyphFragmentNode)
FRAME_ID(nsISVGSVGFrame)
FRAME_ID(nsIScrollableFrame)
FRAME_ID(nsIScrollbarMediator)
FRAME_ID(nsISelectControlFrame)
FRAME_ID(nsIStatefulFrame)
FRAME_ID(nsITableCellLayout)
FRAME_ID(nsITableLayout)
FRAME_ID(nsITextControlFrame)
FRAME_ID(nsITreeBoxObject)
FRAME_ID(nsImageBoxFrame)
FRAME_ID(nsImageControlFrame)
FRAME_ID(nsImageFrame)
FRAME_ID(nsInlineFrame)
FRAME_ID(nsLeafBoxFrame)
FRAME_ID(nsLeafFrame)
FRAME_ID(nsLegendFrame)
FRAME_ID(nsListBoxBodyFrame)
FRAME_ID(nsListControlFrame)
FRAME_ID(nsListItemFrame)
FRAME_ID(nsMathMLContainerFrame)
FRAME_ID(nsMathMLFrame)
FRAME_ID(nsMathMLmactionFrame)
FRAME_ID(nsMathMLmathBlockFrame)
FRAME_ID(nsMathMLmathInlineFrame)
FRAME_ID(nsMathMLmencloseFrame)
FRAME_ID(nsMathMLmfencedFrame)
FRAME_ID(nsMathMLmfracFrame)
FRAME_ID(nsMathMLmmultiscriptsFrame)
FRAME_ID(nsMathMLmoFrame)
FRAME_ID(nsMathMLmoverFrame)
FRAME_ID(nsMathMLmpaddedFrame)
FRAME_ID(nsMathMLmphantomFrame)
FRAME_ID(nsMathMLmrootFrame)
FRAME_ID(nsMathMLmrowFrame)
FRAME_ID(nsMathMLmspaceFrame)
FRAME_ID(nsMathMLmsqrtFrame)
FRAME_ID(nsMathMLmstyleFrame)
FRAME_ID(nsMathMLmsubFrame)
FRAME_ID(nsMathMLmsubsupFrame)
FRAME_ID(nsMathMLmsupFrame)
FRAME_ID(nsMathMLmtableFrame)
FRAME_ID(nsMathMLmtableOuterFrame)
FRAME_ID(nsMathMLmtdFrame)
FRAME_ID(nsMathMLmtdInnerFrame)
FRAME_ID(nsMathMLmtrFrame)
FRAME_ID(nsMathMLmunderFrame)
FRAME_ID(nsMathMLmunderoverFrame)
FRAME_ID(nsMathMLsemanticsFrame)
FRAME_ID(nsMathMLTokenFrame)
FRAME_ID(nsMenuBarFrame)
FRAME_ID(nsMenuFrame)
FRAME_ID(nsMenuPopupFrame)
FRAME_ID(nsMeterFrame)
FRAME_ID(nsObjectFrame)
FRAME_ID(nsPageBreakFrame)
FRAME_ID(nsPageContentFrame)
FRAME_ID(nsPageFrame)
FRAME_ID(nsPlaceholderFrame)
FRAME_ID(nsPopupSetFrame)
FRAME_ID(nsProgressFrame)
FRAME_ID(nsProgressMeterFrame)
FRAME_ID(nsResizerFrame)
FRAME_ID(nsRootBoxFrame)
FRAME_ID(nsScrollbarButtonFrame)
FRAME_ID(nsScrollbarFrame)
FRAME_ID(nsSelectsAreaFrame)
FRAME_ID(nsSimplePageSequenceFrame)
FRAME_ID(nsSliderFrame)
FRAME_ID(nsSplittableFrame)
FRAME_ID(nsSplitterFrame)
FRAME_ID(nsStackFrame)
FRAME_ID(nsSubDocumentFrame)
FRAME_ID(nsSVGAFrame)
FRAME_ID(nsSVGClipPathFrame)
FRAME_ID(nsSVGContainerFrame)
FRAME_ID(nsSVGDisplayContainerFrame)
FRAME_ID(SVGFEContainerFrame)
FRAME_ID(SVGFEImageFrame)
FRAME_ID(SVGFELeafFrame)
FRAME_ID(SVGFEUnstyledLeafFrame)
FRAME_ID(nsSVGFilterFrame)
FRAME_ID(nsSVGForeignObjectFrame)
FRAME_ID(nsSVGGenericContainerFrame)
FRAME_ID(nsSVGGeometryFrame)
FRAME_ID(nsSVGGFrame)
FRAME_ID(nsSVGGlyphFrame)
FRAME_ID(nsSVGGradientFrame)
FRAME_ID(nsSVGImageFrame)
FRAME_ID(nsSVGInnerSVGFrame)
FRAME_ID(nsSVGLinearGradientFrame)
FRAME_ID(nsSVGMarkerFrame)
FRAME_ID(nsSVGMaskFrame)
FRAME_ID(nsSVGOuterSVGFrame)
FRAME_ID(nsSVGOuterSVGAnonChildFrame)
FRAME_ID(nsSVGPaintServerFrame)
FRAME_ID(nsSVGPathGeometryFrame)
FRAME_ID(nsSVGPatternFrame)
FRAME_ID(nsSVGRadialGradientFrame)
FRAME_ID(nsSVGStopFrame)
FRAME_ID(nsSVGSwitchFrame)
FRAME_ID(nsSVGTextContainerFrame)
FRAME_ID(nsSVGTextFrame)
FRAME_ID(nsSVGTextFrame2)
FRAME_ID(nsSVGTextPathFrame)
FRAME_ID(nsSVGTSpanFrame)
FRAME_ID(nsSVGUseFrame)
FRAME_ID(SVGViewFrame)
FRAME_ID(nsTableCaptionFrame)
FRAME_ID(nsTableCellFrame)
FRAME_ID(nsTableColFrame)
FRAME_ID(nsTableColGroupFrame)
FRAME_ID(nsTableFrame)
FRAME_ID(nsTableOuterFrame)
FRAME_ID(nsTableRowFrame)
FRAME_ID(nsTableRowGroupFrame)
FRAME_ID(nsTextBoxFrame)
FRAME_ID(nsTextControlFrame)
FRAME_ID(nsTextFrame)
FRAME_ID(nsTitleBarFrame)
FRAME_ID(nsTreeBodyFrame)
FRAME_ID(nsTreeColFrame)
FRAME_ID(nsVideoFrame)
FRAME_ID(nsXULLabelFrame)
FRAME_ID(nsXULScrollFrame)
FRAME_ID(ViewportFrame)

==> xulrunner-34.0a1.en-US.win32.sdk.zip: xulrunner-sdk/include/nsFrameIdList.h <==
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

FRAME_ID(BRFrame)
FRAME_ID(nsAutoRepeatBoxFrame)
FRAME_ID(nsBCTableCellFrame)
FRAME_ID(nsBlockFrame)
FRAME_ID(nsBox)
FRAME_ID(nsBoxFrame)
FRAME_ID(nsBulletFrame)
FRAME_ID(nsButtonBoxFrame)
FRAME_ID(nsCanvasFrame)
FRAME_ID(nsColorControlFrame)
FRAME_ID(nsColumnSetFrame)
FRAME_ID(nsComboboxControlFrame)
FRAME_ID(nsComboboxDisplayFrame)
FRAME_ID(nsContainerFrame)
FRAME_ID(nsContinuingTextFrame)
FRAME_ID(nsDeckFrame)
FRAME_ID(nsDocElementBoxFrame)
FRAME_ID(nsFieldSetFrame)
FRAME_ID(nsFileControlFrame)
FRAME_ID(nsFirstLetterFrame)
FRAME_ID(nsFirstLineFrame)
FRAME_ID(nsFlexContainerFrame)
FRAME_ID(nsFormControlFrame)
FRAME_ID(nsFrame)
FRAME_ID(nsGfxButtonControlFrame)
FRAME_ID(nsGfxCheckboxControlFrame)
FRAME_ID(nsGfxRadioControlFrame)
FRAME_ID(nsGridContainerFrame)
FRAME_ID(nsGridRowGroupFrame)
FRAME_ID(nsGridRowLeafFrame)
FRAME_ID(nsGroupBoxFrame)
FRAME_ID(nsHTMLButtonControlFrame)
FRAME_ID(nsHTMLCanvasFrame)
FRAME_ID(nsHTMLFramesetBlankFrame)
FRAME_ID(nsHTMLFramesetBorderFrame)
FRAME_ID(nsHTMLFramesetFrame)
FRAME_ID(nsHTMLScrollFrame)
FRAME_ID(nsIAnonymousContentCreator)
FRAME_ID(nsIComboboxControlFrame)
FRAME_ID(nsIFormControlFrame)
FRAME_ID(nsIFrame)
FRAME_ID(nsIFrameFrame)
FRAME_ID(nsIListControlFrame)
FRAME_ID(nsIMathMLFrame)
FRAME_ID(nsIMenuFrame)
FRAME_ID(nsIObjectFrame)
FRAME_ID(nsIPageSequenceFrame)
FRAME_ID(nsIPercentHeightObserver)
FRAME_ID(nsIRootBox)
FRAME_ID(nsISVGChildFrame)
FRAME_ID(nsISVGSVGFrame)
FRAME_ID(nsIScrollableFrame)
FRAME_ID(nsIScrollbarMediator)
FRAME_ID(nsIScrollbarOwner)
FRAME_ID(nsISelectControlFrame)
FRAME_ID(nsIStatefulFrame)
FRAME_ID(nsITableCellLayout)
FRAME_ID(nsITableLayout)
FRAME_ID(nsITextControlFrame)
FRAME_ID(nsITreeBoxObject)
FRAME_ID(nsImageBoxFrame)
FRAME_ID(nsImageControlFrame)
FRAME_ID(nsImageFrame)
FRAME_ID(nsInlineFrame)
FRAME_ID(nsLeafBoxFrame)
FRAME_ID(nsLeafFrame)
FRAME_ID(nsLegendFrame)
FRAME_ID(nsListBoxBodyFrame)
FRAME_ID(nsListControlFrame)
FRAME_ID(nsListItemFrame)
FRAME_ID(nsMathMLContainerFrame)
FRAME_ID(nsMathMLFrame)
FRAME_ID(nsMathMLmactionFrame)
FRAME_ID(nsMathMLmathBlockFrame)
FRAME_ID(nsMathMLmathInlineFrame)
FRAME_ID(nsMathMLmencloseFrame)
FRAME_ID(nsMathMLmfencedFrame)
FRAME_ID(nsMathMLmfracFrame)
FRAME_ID(nsMathMLmmultiscriptsFrame)
FRAME_ID(nsMathMLmoFrame)
FRAME_ID(nsMathMLmoverFrame)
FRAME_ID(nsMathMLmpaddedFrame)
FRAME_ID(nsMathMLmphantomFrame)
FRAME_ID(nsMathMLmrootFrame)
FRAME_ID(nsMathMLmrowFrame)
FRAME_ID(nsMathMLmspaceFrame)
FRAME_ID(nsMathMLmsqrtFrame)
FRAME_ID(nsMathMLmstyleFrame)
FRAME_ID(nsMathMLmtableFrame)
FRAME_ID(nsMathMLmtableOuterFrame)
FRAME_ID(nsMathMLmtdFrame)
FRAME_ID(nsMathMLmtdInnerFrame)
FRAME_ID(nsMathMLmtrFrame)
FRAME_ID(nsMathMLmunderFrame)
FRAME_ID(nsMathMLmunderoverFrame)
FRAME_ID(nsMathMLsemanticsFrame)
FRAME_ID(nsMathMLTokenFrame)
FRAME_ID(nsMenuBarFrame)
FRAME_ID(nsMenuFrame)
FRAME_ID(nsMenuPopupFrame)
FRAME_ID(nsMeterFrame)
FRAME_ID(nsNumberControlFrame)
FRAME_ID(nsObjectFrame)
FRAME_ID(nsPageBreakFrame)
FRAME_ID(nsPageContentFrame)
FRAME_ID(nsPageFrame)
FRAME_ID(nsPlaceholderFrame)
FRAME_ID(nsPopupSetFrame)
FRAME_ID(nsProgressFrame)
FRAME_ID(nsProgressMeterFrame)
FRAME_ID(nsRangeFrame)
FRAME_ID(nsResizerFrame)
FRAME_ID(nsRootBoxFrame)
FRAME_ID(nsRubyBaseContainerFrame)
FRAME_ID(nsRubyBaseFrame)
FRAME_ID(nsRubyFrame)
FRAME_ID(nsRubyTextContainerFrame)
FRAME_ID(nsRubyTextFrame)
FRAME_ID(nsScrollbarButtonFrame)
FRAME_ID(nsScrollbarFrame)
FRAME_ID(nsSelectsAreaFrame)
FRAME_ID(nsSimplePageSequenceFrame)
FRAME_ID(nsSliderFrame)
FRAME_ID(nsSplittableFrame)
FRAME_ID(nsSplitterFrame)
FRAME_ID(nsStackFrame)
FRAME_ID(nsSubDocumentFrame)
FRAME_ID(nsSVGAFrame)
FRAME_ID(nsSVGClipPathFrame)
FRAME_ID(nsSVGContainerFrame)
FRAME_ID(nsSVGDisplayContainerFrame)
FRAME_ID(SVGFEContainerFrame)
FRAME_ID(SVGFEImageFrame)
FRAME_ID(SVGFELeafFrame)
FRAME_ID(SVGFEUnstyledLeafFrame)
FRAME_ID(nsSVGFilterFrame)
FRAME_ID(nsSVGForeignObjectFrame)
FRAME_ID(nsSVGGenericContainerFrame)
FRAME_ID(nsSVGGFrame)
FRAME_ID(nsSVGGradientFrame)
FRAME_ID(nsSVGImageFrame)
FRAME_ID(nsSVGInnerSVGFrame)
FRAME_ID(nsSVGLinearGradientFrame)
FRAME_ID(nsSVGMarkerFrame)
FRAME_ID(nsSVGMarkerAnonChildFrame)
FRAME_ID(nsSVGMaskFrame)
FRAME_ID(nsSVGOuterSVGFrame)
FRAME_ID(nsSVGOuterSVGAnonChildFrame)
FRAME_ID(nsSVGPaintServerFrame)
FRAME_ID(nsSVGPathGeometryFrame)
FRAME_ID(nsSVGPatternFrame)
FRAME_ID(nsSVGRadialGradientFrame)
FRAME_ID(nsSVGStopFrame)
FRAME_ID(nsSVGSwitchFrame)
FRAME_ID(SVGTextFrame)
FRAME_ID(nsSVGUseFrame)
FRAME_ID(SVGViewFrame)
FRAME_ID(nsTableCaptionFrame)
FRAME_ID(nsTableCellFrame)
FRAME_ID(nsTableColFrame)
FRAME_ID(nsTableColGroupFrame)
FRAME_ID(nsTableFrame)
FRAME_ID(nsTableOuterFrame)
FRAME_ID(nsTableRowFrame)
FRAME_ID(nsTableRowGroupFrame)
FRAME_ID(nsTextBoxFrame)
FRAME_ID(nsTextControlFrame)
FRAME_ID(nsTextFrame)
FRAME_ID(nsTitleBarFrame)
FRAME_ID(nsTreeBodyFrame)
FRAME_ID(nsTreeColFrame)
FRAME_ID(nsVideoFrame)
FRAME_ID(nsXULLabelFrame)
FRAME_ID(nsXULScrollFrame)
FRAME_ID(ViewportFrame)
